==> haskell-hspec-wai-json-0.9.0-126-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai-json
version: 0.9.0
id: hspec-wai-json-0.9.0-Gv28BraZTan2B1SnmPTQDk
key: hspec-wai-json-0.9.0-Gv28BraZTan2B1SnmPTQDk
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Testing JSON APIs with hspec-wai
description:
    Testing JSON APIs with hspec-wai
category: Testing
abi: ead4cfb70eecd399d1c949ef854ad19c
exposed: True
exposed-modules:
    Test.Hspec.Wai.JSON
hidden-modules: Paths_hspec_wai_json
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-wai-json-0.9.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-wai-json-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-wai-json-0.9.0
hs-libraries: HShspec-wai-json-0.9.0-Gv28BraZTan2B1SnmPTQDk
depends:
    aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX
    aeson-qq-0.8.2-HwnP6R8G9EmCgv7SCmfehp base-4.11.1.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    hspec-wai-0.9.0-HwLmDPmw6TdLhbqv7WrSUG template-haskell-2.13.0.0
abi-depends: aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX=25adaf2f506e44c8d5bd8da34f9279d5
             aeson-qq-0.8.2-HwnP6R8G9EmCgv7SCmfehp=823db2627ee15b8cf84252b183fa65af
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             hspec-wai-0.9.0-HwLmDPmw6TdLhbqv7WrSUG=2a222f19287f3f29323ee123c69ce186
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-json-0.9.0-129-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai-json
version: 0.9.0
id: hspec-wai-json-0.9.0-8covCcTwFzcGalVW375AvF
key: hspec-wai-json-0.9.0-8covCcTwFzcGalVW375AvF
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Testing JSON APIs with hspec-wai
description:
    Testing JSON APIs with hspec-wai
category: Testing
abi: 0fab94b6ea3a8a95d724f32f93f183ae
exposed: True
exposed-modules:
    Test.Hspec.Wai.JSON
hidden-modules: Paths_hspec_wai_json
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-wai-json-0.9.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-wai-json-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-wai-json-0.9.0
hs-libraries: HShspec-wai-json-0.9.0-8covCcTwFzcGalVW375AvF
depends:
    aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX
    aeson-qq-0.8.2-HwnP6R8G9EmCgv7SCmfehp base-4.11.1.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    hspec-wai-0.9.0-J6OJ7yxq71PB73f04KajDq template-haskell-2.13.0.0
abi-depends: aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX=25adaf2f506e44c8d5bd8da34f9279d5
             aeson-qq-0.8.2-HwnP6R8G9EmCgv7SCmfehp=823db2627ee15b8cf84252b183fa65af
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             hspec-wai-0.9.0-J6OJ7yxq71PB73f04KajDq=c5cb92eb2e8357ec57718c86a4f5db9f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
